@@ -22,7 +22,6 @@ def init_board_statuses():
 
 
 def init_teams():
-    models.Team.objects.all().delete()
     mocks.service_api_get_teams_call(fixtures.API_SERVICE_TEAM_LIST)
     synchronizer = sync.TeamSynchronizer()
     return synchronizer.sync()
@@ -174,6 +173,13 @@ def init_company_types():
     return synchronizer.sync()
 
 
+def init_company_statuses():
+    mocks.company_api_get_company_statuses_call(
+        fixtures.API_COMPANY_STATUS_LIST)
+    synchronizer = sync.CompanyStatusSynchronizer()
+    return synchronizer.sync()
+
+
 def init_locations():
     mocks.service_api_get_locations_call(fixtures.API_SERVICE_LOCATION_LIST)
     synchronizer = sync.LocationSynchronizer()
